@@ -1,4 +1,5 @@
 #include "alloc.h"
+#include <stdlib.h>
 
 #ifdef R_ALLOC
 #include <Rinternals.h>
@@ -7,7 +8,7 @@
 void * m_alloc(size_t size)
 {
 #ifdef R_ALLOC
-    return R_alloc(size / sizeof (char), 1);
+    return R_alloc(size, 1);
 #else
     return malloc(size);
 #endif    
@@ -21,3 +22,10 @@ void m_free(void * ptr)
     free(ptr);
 #endif
 }
+
+void m_free_ptrs(void ** ptrs, int n)
+{
+    for (int i = 0; i < n; i++)
+        m_free(ptrs[i]);
+}
+
