@@ -3,6 +3,7 @@
 
 #include "matrix.h"
 #include "energy.h"
+#include "model.h"
 
 struct cec_temp_data
 {
@@ -12,28 +13,38 @@ struct cec_temp_data
     struct cec_matrix ** t_covariance_matrices;
 };
 
-struct cec_context
+struct cec_input
 {
-    /*
-     * Input parameters.
-     */
-    struct cec_matrix * points;
-    struct cec_matrix * centers;
-    struct cross_entropy_context ** cross_entropy_contexts;
-    cross_entropy_function * cross_entropy_functions;
+    const struct cec_matrix * points;
+    const struct cec_matrix * centers;
+    struct cec_model ** models;
     int max_iterations;
     int min_card;
+};
 
-    /*
-     * CEC result (output parameters).
-     * Memory must be allocated before performing the algorithm.
-     */
+struct cec_results
+{
+    struct cec_matrix * centers;
     int * clustering_vector;
     int * clusters_number;
     int iterations;
     double * energy;
     struct cec_matrix ** covriances;
     int error;
+};
+
+struct cec_context
+{
+    /*
+     * Input parameters.
+     */
+    struct cec_input * input;
+
+    /*
+     * CEC result (output parameters).
+     * Memory must be allocated before performing the algorithm.
+     */
+    struct cec_results * results;
 
     /*
      * Temporary data. 
@@ -45,13 +56,12 @@ struct cec_context
 struct cec_matrix ** create_cec_matrix_array(int m, int n, int l);
 
 struct cec_context * create_cec_context(
-	struct cec_matrix * points,
-	struct cec_matrix * centers,
-	struct cross_entropy_context ** cross_entropy_contexts,
-	cross_entropy_function * cross_entropy_functions,
-	int max_iterations,
-	int min_card
-	);
+        const struct cec_matrix * points,
+        const struct cec_matrix * centers,
+        struct cec_model **,
+        int max_iterations,
+        int min_card
+        );
 
 void destroy_cec_matrix_array(struct cec_matrix ** matrix_array, int l);
 
